@@ -123,23 +123,6 @@ class GuiManager(object):
         """
         Populate the main window with widgets
         """
-        # Preload all perspectives
-        self.loadAllPerspectives()
-
-        # Add FileDialog widget as docked
-        self.filesWidget = DataExplorerWindow(self._parent, self, manager=self._data_manager)
-        ObjectLibrary.addObject('DataExplorer', self.filesWidget)
-
-        self.dockedFilesWidget = QDockWidget("Data Explorer", self._workspace)
-        self.dockedFilesWidget.setFloating(False)
-        self.dockedFilesWidget.setWidget(self.filesWidget)
-
-        # Modify menu items on widget visibility change
-        self.dockedFilesWidget.visibilityChanged.connect(self.updateContextMenus)
-
-        self._workspace.addDockWidget(Qt.LeftDockWidgetArea, self.dockedFilesWidget)
-        self._workspace.resizeDocks([self.dockedFilesWidget], [305], Qt.Horizontal)
-
         # Add the console window as another docked widget
         self.logDockWidget = QDockWidget("Log Explorer", self._workspace)
         self.logDockWidget.setObjectName("LogDockWidget")
@@ -150,6 +133,21 @@ class GuiManager(object):
         self.logDockWidget.setWidget(self.listWidget)
         self._workspace.addDockWidget(Qt.BottomDockWidgetArea, self.logDockWidget)
 
+        # Preload all perspectives
+        self.loadAllPerspectives()
+        # Add FileDialog widget as docked
+        self.filesWidget = DataExplorerWindow(self._parent, self, manager=self._data_manager)
+        ObjectLibrary.addObject('DataExplorer', self.filesWidget)
+
+        self.dockedFilesWidget = QDockWidget("Data Explorer", self._workspace)
+        self.dockedFilesWidget.setFloating(False)
+        self.dockedFilesWidget.setWidget(self.filesWidget)
+        # Modify menu items on widget visibility change
+        self.dockedFilesWidget.visibilityChanged.connect(self.updateContextMenus)
+
+        self._workspace.addDockWidget(Qt.LeftDockWidgetArea, self.dockedFilesWidget)
+        self._workspace.resizeDocks([self.dockedFilesWidget], [305], Qt.Horizontal)
+
         # Add other, minor widgets
         self.ackWidget = Acknowledgements()
         self.aboutWidget = AboutBox()
@@ -168,8 +166,8 @@ class GuiManager(object):
         self.results_frame.setVisible(False)
         self.results_panel.windowClosedSignal.connect(lambda: self.results_frame.setVisible(False))
 
-        self._workspace.toolBar.setVisible(LocalConfig.TOOLBAR_SHOW)
-        self._workspace.actionHide_Toolbar.setText("Show Toolbar")
+        custom_config = get_custom_config()
+        self._workspace.toolBar.setVisible(custom_config.TOOLBAR_SHOW)
 
         # Add calculators - floating for usability
         self.SLDCalculator = SldPanel(self)
