@@ -86,6 +86,8 @@ class PlotterWidget(PlotterBase):
         self.toolbar._actions['pan'].triggered.connect(self._pan)
         self.toolbar._actions['zoom'].triggered.connect(self._zoom)
 
+        self.legendVisible = True
+
         parent.geometry()
 
     @property
@@ -159,6 +161,7 @@ class PlotterWidget(PlotterBase):
         ax = self.ax
         x = data.view.x
         y = data.view.y
+        label = data.name # was self._title
 
         # Marker symbol. Passed marker is one of matplotlib.markers characters
         # Alternatively, picked up from Data1D as an int index of PlotUtilities.SHAPES dict
@@ -202,22 +205,22 @@ class PlotterWidget(PlotterBase):
         l_width = markersize * 0.4
         if marker == '-' or marker == '--':
             line = self.ax.plot(x, y, color=color, lw=l_width, marker='',
-                             linestyle=marker, label=self._title, zorder=10)[0]
+                             linestyle=marker, label=label, zorder=10)[0]
 
         elif marker == 'vline':
             y_min = min(y)*9.0/10.0 if min(y) < 0 else 0.0
             line = self.ax.vlines(x=x, ymin=y_min, ymax=y, color=color,
-                            linestyle='-', label=self._title, lw=l_width, zorder=1)
+                            linestyle='-', label=label, lw=l_width, zorder=1)
 
         elif marker == 'step':
             line = self.ax.step(x, y, color=color, marker='', linestyle='-',
-                                label=self._title, lw=l_width, zorder=1)[0]
+                                label=label, lw=l_width, zorder=1)[0]
 
         else:
             # plot data with/without errorbars
             if hide_error:
                 line = ax.plot(x, y, marker=marker, color=color, markersize=markersize,
-                        linestyle='', label=self._title, picker=True)
+                        linestyle='', label=label, picker=True)
             else:
                 dy = data.view.dy
                 # Convert tuple (lo,hi) to array [(x-lo),(hi-x)]
@@ -234,7 +237,7 @@ class PlotterWidget(PlotterBase):
                             markersize=markersize,
                             lolims=False, uplims=False,
                             xlolims=False, xuplims=False,
-                            label=self._title,
+                            label=label,
                             zorder=1,
                             picker=True)
 
@@ -256,7 +259,7 @@ class PlotterWidget(PlotterBase):
                 self.legend = ax.legend(loc='upper right', shadow=True)
             if self.legend:
                 self.legend.set_picker(True)
-
+            self.legend.set_visible(self.legendVisible)
         # Current labels for axes
         if self.yLabel and not is_fit:
             ax.set_ylabel(self.yLabel)
@@ -301,7 +304,7 @@ class PlotterWidget(PlotterBase):
         """
         Resize the legend window/font on canvas resize
         """
-        if not self.showLegend:
+        if not self.showLegend or not self.legendVisible:
             return
         width = _legendResize(event.width, self.parent)
         # resize the legend to follow the canvas width.
@@ -574,7 +577,6 @@ class PlotterWidget(PlotterBase):
         Resets the chart X and Y ranges to their original values
         """
         # Clear graph and plot everything again
-        mpl.pyplot.cla()
         self.ax.cla()
         self.setRange = None
         for ids in self.plot_dict:
@@ -651,7 +653,6 @@ class PlotterWidget(PlotterBase):
         xl = self.ax.xaxis.label.get_text()
         yl = self.ax.yaxis.label.get_text()
 
-        mpl.pyplot.cla()
         self.ax.cla()
 
         # Recreate Artist bindings after plot clear
@@ -692,7 +693,7 @@ class PlotterWidget(PlotterBase):
         marker = selected_plot.symbol
         marker_size = selected_plot.markersize
         # plot name
-        legend = selected_plot.title
+        legend = selected_plot.name
         plotPropertiesWidget = PlotProperties(self,
                                 color=color,
                                 marker=marker,
@@ -703,7 +704,7 @@ class PlotterWidget(PlotterBase):
             selected_plot.markersize = plotPropertiesWidget.markersize()
             selected_plot.custom_color = plotPropertiesWidget.color()
             selected_plot.symbol = plotPropertiesWidget.marker()
-            selected_plot.title = plotPropertiesWidget.legend()
+            selected_plot.name = plotPropertiesWidget.legend()
             # Redraw the plot
             self.replacePlot(id, selected_plot)
 
@@ -721,7 +722,6 @@ class PlotterWidget(PlotterBase):
         self.plot_dict = {}
 
         # Clean the canvas
-        mpl.pyplot.cla()
         self.ax.cla()
 
         # Recreate the plots but reverse the error flag for the current
@@ -794,8 +794,9 @@ class PlotterWidget(PlotterBase):
         if not self.showLegend:
             return
 
-        visible = self.legend.get_visible()
-        self.legend.set_visible(not visible)
+        #visible = self.legend.get_visible()
+        self.legendVisible = not self.legendVisible
+        self.legend.set_visible(self.legendVisible)
         self.canvas.draw_idle()
 
     def onMplMouseDown(self, event):
