@@ -139,7 +139,7 @@ class BaseInteractor(object):
             self.clickx, self.clicky = ev.xdata, ev.ydata
             self.move(ev.xdata, ev.ydata, ev)
         else:
-            self.restore()
+            self.restore(ev)
         self.base.update()
         return True
 
@@ -151,7 +151,7 @@ class BaseInteractor(object):
         Calls move() to update the state.  Calls restore() on escape.
         """
         if ev.key == 'escape':
-            self.restore()
+            self.restore(ev)
         elif ev.key in ['up', 'down', 'right', 'left']:
             dx, dy = self.dpixel(self.clickx, self.clicky, nudge=ev.control)
             if ev.key == 'up':
