@@ -148,8 +148,11 @@ class Guinier(Transform):
         return [self.radius, self.scale], [self.dradius, self.dscale]
 
     def evaluate_model(self, x):
-        """
-        return F(x)= scale* e-((radius*x)**2/3)
+        r"""
+        return calculated I(q) for the model
+
+        Calculates the Guinier expression
+        $F(x)= s * \exp\left(-(r x)^{2/3}\right)$
         """
         return self._guinier(x)
 
@@ -167,14 +170,16 @@ class Guinier(Transform):
         return np.array([math.sqrt(err) for err in diq2])
 
     def _guinier(self, x):
-        """
+        r"""
         Retrieve the guinier function after apply an inverse guinier function
         to x
-        Compute a F(x) = scale* e-((radius*x)**2/3).
+        Compute $F(x) = s * \exp\left(-(r x)^{2/3}\right)$.
 
         :param x: a vector of q values
-        :param scale: the scale value
-        :param radius: the guinier radius value
+
+        Also uses:
+         - self.scale: $s$, the scale value
+         - self.radius: $r$, the guinier radius value
 
         :return: F(x)
         """
@@ -204,7 +209,7 @@ class PowerLaw(Transform):
 
         :param value: q-value
 
-        :return: log(q)
+        :return: $\log(q)$
         """
         return math.log(value)
 
@@ -291,7 +296,7 @@ class Extrapolator(object):
 
     def fit(self, power=None, qmin=None, qmax=None):
         """
-        Fit data for y = ax + b  return a and b
+        Fit data for $y = ax + b$  return $a$ and $b$
 
         :param power: a fixed, otherwise None
         :param qmin: Minimum Q-value
@@ -419,6 +424,25 @@ class InvariantCalculator(object):
         # Extrapolation range
         self._low_q_limit = Q_MINIMUM
 
+    @property
+    def background(self):
+        return self._background
+
+    @background.setter
+    def background(self, value):
+        self._background = value
+
+    @property
+    def scale(self):
+        return self._scale
+
+    @scale.setter
+    def scale(self, value):
+        self._scale = value
+
+    def set_data(self, data):
+        self._data = self._get_data(data)
+
     def _get_data(self, data):
         """
         :note: this function must be call before computing any type
@@ -604,19 +628,26 @@ class InvariantCalculator(object):
             return self._low_extrapolation_power_fitted
         return self._high_extrapolation_power_fitted
 
-    def get_qstar_low(self):
+    def get_qstar_low(self, low_q_limit=None):
         """
         Compute the invariant for extrapolated data at low q range.
 
-        Implementation:
+        Implementation: ::
+
             data = self._get_extra_data_low()
             return self._get_qstar()
 
         :return q_star: the invariant for data extrapolated at low q.
         """
         # Data boundaries for fitting
-        qmin = self._data.x[0]
         qmax = self._data.x[int(self._low_extrapolation_npts - 1)]
+        # Allow minimum q to be passed as an argument
+        if not low_q_limit or low_q_limit < self._data.x[0] or low_q_limit >= qmax:
+            qmin = self._data.x[0]
+        else:
+            qmin = low_q_limit
+        # Distribution starting point
+        self._low_q_limit = low_q_limit if low_q_limit else Q_MINIMUM
 
         # Extrapolate the low-Q data
         p, _ = self._fit(model=self._low_extrapolation_function,
@@ -625,38 +656,37 @@ class InvariantCalculator(object):
                          power=self._low_extrapolation_power)
         self._low_extrapolation_power_fitted = p[0]
 
-        # Distribution starting point
-        self._low_q_limit = Q_MINIMUM
-        if Q_MINIMUM >= qmin:
-            self._low_q_limit = qmin / 10
-
-        data = self._get_extrapolated_data(\
-                                    model=self._low_extrapolation_function,
-                                    npts=INTEGRATION_NSTEPS,
-                                    q_start=self._low_q_limit, q_end=qmin)
+        data = self._get_extrapolated_data(
+            model=self._low_extrapolation_function,
+            npts=INTEGRATION_NSTEPS, q_start=self._low_q_limit, q_end=qmin)
 
         # Systematic error
         # If we have smearing, the shape of the I(q) distribution at low Q will
         # may not be a Guinier or simple power law. The following is
         # a conservative estimation for the systematic error.
-        err = qmin * qmin * math.fabs((qmin - self._low_q_limit) * \
-                                  (data.y[0] - data.y[INTEGRATION_NSTEPS - 1]))
+        err = qmin * qmin * math.fabs((qmin - self._low_q_limit) * (data.y[0] - data.y[INTEGRATION_NSTEPS - 1]))
         return self._get_qstar(data), self._get_qstar_uncertainty(data) + err
 
-    def get_qstar_high(self):
+    def get_qstar_high(self, high_q_limit=None):
         """
         Compute the invariant for extrapolated data at high q range.
 
-        Implementation:
+        Implementation: ::
+
             data = self._get_extra_data_high()
             return self._get_qstar()
 
         :return q_star: the invariant for data extrapolated at high q.
         """
         # Data boundaries for fitting
-        x_len = len(self._data.x) - 1
-        qmin = self._data.x[int(x_len - (self._high_extrapolation_npts - 1))]
-        qmax = self._data.x[int(x_len)]
+        x_len = int(len(self._data.x) - 1)
+        qmin = self._data.x[int(x_len - self._high_extrapolation_npts)]
+        if not high_q_limit or high_q_limit > self._data.x[x_len] or high_q_limit <= qmin:
+            qmax = self._data.x[x_len]
+        else:
+            qmax = high_q_limit
+
+        high_q_limit = high_q_limit if high_q_limit else Q_MAXIMUM
 
         # fit the data with a model to get the appropriate parameters
         p, _ = self._fit(model=self._high_extrapolation_function,
@@ -666,10 +696,9 @@ class InvariantCalculator(object):
         self._high_extrapolation_power_fitted = p[0]
 
         #create new Data1D to compute the invariant
-        data = self._get_extrapolated_data(\
-                                    model=self._high_extrapolation_function,
-                                    npts=INTEGRATION_NSTEPS,
-                                    q_start=qmax, q_end=Q_MAXIMUM)
+        data = self._get_extrapolated_data(
+            model=self._high_extrapolation_function,
+            npts=INTEGRATION_NSTEPS, q_start=qmax, q_end=high_q_limit)
 
         return self._get_qstar(data), self._get_qstar_uncertainty(data)
 
@@ -816,11 +845,15 @@ class InvariantCalculator(object):
 
         Historically, Sv was computed with the invariant and the Porod
         constant so as not to have to know the contrast in order to get the
-        Sv as:
+        Sv as: ::
+
             surface = (pi * V * (1- V) * porod_const) / q_star
+
         However, that turns out to be a pointless exercise since it
         also requires a knowledge of the volume fractions and from the
-        volumer fraction and the invariant the contrast can be calculated as:
+        volume fraction and the invariant the contrast can be calculated
+        as: ::
+
             contrast**2 = q_star / (2 * pi**2 * V * (1- V))
 
         Thus either way, mathematically it is always identical to computing
@@ -829,10 +862,11 @@ class InvariantCalculator(object):
         circular approach.
 
         Implementation: ::
-           Given the above, as of SasView 4.3 and 5.0.2 we compute Sv simply
-           from the Porod Constant and the contrast between the two phases as:
-             surface = porod_const / (2 * pi contrast**2) 
 
+            Given the above, as of SasView 4.3 and 5.0.2 we compute Sv simply
+            from the Porod Constant and the contrast between the two phases as:
+
+            surface = porod_const / (2 * pi contrast**2)
 
         :param contrast: contrast between the two phases
         :param porod_const: Porod constant
@@ -849,7 +883,7 @@ class InvariantCalculator(object):
 
     def get_volume_fraction(self, contrast, extrapolation=None):
         """
-        Compute volume fraction is deduced as follow: ::
+        Compute volume fraction is deduced as follows: ::
 
             q_star = 2*(pi*contrast)**2* volume( 1- volume)
             for k = 10^(-8)*q_star/(2*(pi*|contrast|)**2)
@@ -924,16 +958,19 @@ class InvariantCalculator(object):
 
             sigV = dV/dq_star * sigq_star
             
-            so that
+        so that: ::
+
             sigV = (k * sigq_star) /(q_star * math.sqrt(1 - 4 * k))
 
             for k = 10^(-8)*q_star/(2*(pi*|contrast|)**2)
 
-            10^(-8) converts from cm^-1 to A^-1
-            q_star: the invariant, in cm^-1A^-3, including extrapolated values
-                if they have been requested
-            dq_star: the invariant uncertainty
-            dV: the volume uncertainty
+        Notes:
+
+        - 10^(-8) converts from cm^-1 to A^-1
+        - q_star: the invariant, in cm^-1A^-3, including extrapolated values
+          if they have been requested
+        - dq_star: the invariant uncertainty
+        - dV: the volume uncertainty
 
         The uncertainty will be set to -1 if it can't be computed.
 
@@ -964,13 +1001,17 @@ class InvariantCalculator(object):
         from the contrast and porod_constant wich are currently user inputs
         with no option for any uncertainty so no uncertainty can be calculated.
         However we include the uncertainty computation for future use if and
-        when these values get an uncertainty. This is given as:
+        when these values get an uncertainty. This is given as: ::
+
+            ds = sqrt[(s\'_cp)**2 * dcp**2 + (s\'_contrast)**2 * dcontrast**2]
+
+        where s'_x is the partial derivative of S with respect to x
+
+        which gives (this should be checked before using in anger): ::
 
-            ds = sqrt[(s'_cp)**2 * dcp**2 + (s'_contrast)**2 * dcontrast**2]
-            where s'_x is the partial derivative of S with respect to x 
-        which gives (this should be checked before using in anger)
             ds = sqrt((dporod_const**2 * contrast**2 + 4 * (porod_const *
                           dcontrast)**2) / (4 * pi**2 * contrast**6))
+
         We also assume some users will never enter a value for uncertainty so
         allow for None even when it is an option.
 
