@@ -16,7 +16,7 @@ __appname__ = "SasView"
 __version__ = sas.sasview.__version__
 __build__ = sas.sasview.__build__
 __download_page__ = 'https://github.com/SasView/sasview/releases'
-__update_URL__ = 'http://www.sasview.org/latestversion.json'
+__update_URL__ = 'https://www.sasview.org/latestversion.json'
 
 # Debug message flag
 __EVT_DEBUG__ = False
@@ -52,7 +52,7 @@ _acknowledgement =  \
 '''This work was originally developed as part of the DANSE project funded by the US NSF under Award DMR-0520547,\n but is currently maintained by a collaboration between UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO, TU Delft, DLS, and the scattering community.\n\n SasView also contains code developed with funding from the EU Horizon 2020 programme under the SINE2020 project (Grant No 654000).\nA list of individual contributors can be found at: http://www.sasview.org/contact.html
 '''
 
-_homepage = "http://www.sasview.org"
+_homepage = "https://www.sasview.org"
 _download = __download_page__
 _authors = []
 _paper = "http://sourceforge.net/p/sasview/tickets/"
@@ -77,22 +77,22 @@ _dls_logo = os.path.join(icon_path, "dls_logo.png")
 _nsf_logo = os.path.join(icon_path, "nsf_logo.png")
 _danse_logo = os.path.join(icon_path, "danse_logo.png")
 _inst_logo = os.path.join(icon_path, "utlogo.gif")
-_nist_url = "http://www.nist.gov/"
-_umd_url = "http://www.umd.edu/"
-_sns_url = "http://neutrons.ornl.gov/"
-_ornl_url = "http://neutrons.ornl.gov/"
-_nsf_url = "http://www.nsf.gov"
-_isis_url = "http://www.isis.stfc.ac.uk/"
-_ess_url = "http://ess-scandinavia.eu/"
-_ill_url = "http://www.ill.eu/"
-_ansto_url = "http://www.ansto.gov.au/"
-_tudelft_url = "http://www.tnw.tudelft.nl/en/cooperation/facilities/reactor-instituut-delft/"
-_dls_url = "http://www.diamond.ac.uk/"
-_danse_url = "http://www.cacr.caltech.edu/projects/danse/release/index.html"
-_inst_url = "http://www.utk.edu"
+_nist_url = "https://www.nist.gov/"
+_umd_url = "https://www.umd.edu/"
+_sns_url = "https://neutrons.ornl.gov/"
+_ornl_url = "https://neutrons.ornl.gov/"
+_nsf_url = "https://www.nsf.gov"
+_isis_url = "https://www.isis.stfc.ac.uk/"
+_ess_url = "https://europeanspallationsource.se/"
+_ill_url = "https://www.ill.eu/"
+_ansto_url = "https://www.ansto.gov.au/"
+_tudelft_url = "https://www.tudelft.nl/en/faculty-of-applied-sciences/business/facilities/reactor-institute-delft"
+_dls_url = "https://www.diamond.ac.uk/"
+_danse_url = "https://www.its.caltech.edu/~matsci/btf/DANSE_web_page.html"
+_inst_url = "https://www.utk.edu"
 _corner_image = os.path.join(icon_path, "angles_flat.png")
 _welcome_image = os.path.join(icon_path, "SVwelcome.png")
-_copyright = "(c) 2009 - 2020, UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO, TU Delft and DLS"
+_copyright = "(c) 2009 - 2023, UTK, UMD, NIST, ORNL, ISIS, ESS, ILL, ANSTO, TU Delft and DLS"
 marketplace_url = "http://marketplace.sasview.org/"
 
 #edit the list of file state your plugin can read
